#
# spec file for package proteus
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define pythons python3
%define mypython python3
%define mysitelib %python3_sitelib
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define mysitelib %{expand:%%%{mypython}_sitelib}
%endif

%define majorver 6.0
Name:           proteus
Version:        %{majorver}.8
Release:        3.5
Summary:        A library to access Tryton's modules like a client
License:        GPL-3.0-or-later
Group:          Productivity/Office/Management
URL:            http://www.tryton.org/
Source0:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
Source1:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz.asc
Source2:        https://keybase.io/cedrickrier/pgp_keys.asc?fingerprint=7C5A4360F6DF81ABA91FD54D6FF50AFE03489130#/%{name}.keyring
# List of additional build dependencies
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-pip
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros

BuildRequires:  %{mypython}-defusedxml
BuildRequires:  %{mypython}-python-dateutil

BuildRequires:  trytond
Requires:       %{mypython}-defusedxml
Requires:       %{mypython}-python-dateutil
Requires:       trytond
BuildArch:      noarch

%description
Proteus allows you to access Tryton's modules like a client. Useful for automation, data load etc.

%prep
%setup -q

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{mysitelib}

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}%{mysitelib}
%pyunittest discover -v

%files
%defattr(-,root,root)
%{mysitelib}/proteus*
%doc README.rst
%license LICENSE

%changelog
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- add %%{?sle15_python_module_pythons}
* Wed Oct 18 2023 Ben Greiner <code@bnavigator.de>
- Clean up deprecated python packaging patterns
- Activate unittests
- Clean up dependencies
- Use PEP517 build and install
* Tue Oct 17 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Remove %%python3_install prefix and root options, that's included in
  the macro by default.
* Mon Feb  6 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.8 - Bugfix Release
* Fri Nov 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.7 - Bugfix Release
* Mon Apr 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.6 - Bugfix Release
* Wed Mar  2 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.5 - Bugfix Release
* Sat Feb 12 2022 Axel Braun <axel.braun@gmx.de>
- Version bump to Tryton 6.0 series
* Tue Jan 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 5.0.11 - Bugfix Release
* Mon Dec  6 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.10 - Bugfix Release
* Fri Jul  2 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.9 - Bugfix Release
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Wed Nov 11 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.8 - Bugfix Release
* Tue Dec  3 2019 Axel Braun <axel.braun@gmx.de>
- Version 5.0.7 - Bugfix Release
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.6 (GNU Health 3.6 series)
* Mon Nov 11 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.9 - Bugfix Release
* Thu Oct 24 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.8 - Bugfix Release
* Sun Sep 15 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.7 - Bugfix Release
* Fri May 17 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.6 - Bugfix Release
* Mon Dec 10 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.6.5 - Bugfix Release
* Wed Jul 11 2018 axel.braun@gmx.de
- Version 4.2.4 - Bugfix Release (boo#1107771)
* Sat May 12 2018 axel.braun@gmx.de
- Version 4.2.3 - Bugfix Release
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.2 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.1 - Bugfix Release
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Sat May 14 2016 axel.braun@gmx.de
- version 4.0
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Sat Oct 26 2013 axel.braun@gmx.de
- initial build on OBS
